@@ -1,6 +1,9 @@
+from typing import Optional
+
 from .base import TelegramStructure, Field
 from .photo_size import PhotoSize
 from .mask_position import MaskPosition
+from .file import File
 
 
 class Sticker(TelegramStructure):
@@ -18,6 +21,8 @@ class Sticker(TelegramStructure):
     set_name = Field()
     mask_position = Field()
     file_size = Field()
+    is_video = Field()
+    premium_animation = Field()
 
     def __init__(self,
                  file_id: str,
@@ -25,11 +30,13 @@ class Sticker(TelegramStructure):
                  width: int,
                  height: int,
                  is_animated: bool,
-                 thumb: PhotoSize = None,
-                 emoji: str = None,
-                 set_name: str = None,
-                 mask_position: MaskPosition = None,
-                 file_size: int = None,
+                 is_video: bool,
+                 thumb: Optional[PhotoSize] = None,
+                 emoji: Optional[str] = None,
+                 set_name: Optional[str] = None,
+                 mask_position: Optional[MaskPosition] = None,
+                 file_size: Optional[int] = None,
+                 premium_animation: Optional[File] = None
                  ):
         self.file_id = \
             Field(file_id, [str])
@@ -45,6 +52,9 @@ class Sticker(TelegramStructure):
 
         self.is_animated = \
             Field(is_animated, [bool])
+        
+        self.is_video = \
+            Field(is_video, [bool])
 
         self.thumb = \
             Field(thumb, [PhotoSize])
@@ -60,3 +70,6 @@ class Sticker(TelegramStructure):
 
         self.file_size = \
             Field(file_size, [int])
+        
+        self.premium_animation = \
+            Field(premium_animation, [File])
